<?php
/**
*
* @package Pushsafer.com
* @author pushsafer.com Kevin Siml
* @copyright (c) 2017 by pushsafer.com
* @license http://opensource.org/licenses/gpl-license.php GNU Public License
*
*/

namespace appzer\pushsafer\event;

/**
* Event listener
*/
use Symfony\Component\EventDispatcher\EventSubscriberInterface;

class listener implements EventSubscriberInterface
{

	static public function getSubscribedEvents()
	{
		return array(
			'core.ucp_register_user_row_after'		=> 'ucp_register_user_row_after',
			'core.acp_board_config_edit_add'	=> 'add_pushsafer_configs',
		);
	}

	/**
	* Add config vars to ACP Board Settings
	*
	* @param object $event The event object
	* @return null
	* @access public
	*/
	public function add_pushsafer_configs($event)
	{
		// Load language file
		$this->user->add_lang_ext('appzer/pushsafer', 'pushsafer');

		// Add a config to the settings mode, after board_timezone
		if ($event['mode'] == 'settings' && isset($event['display_vars']['vars']['board_timezone']))
		{
			// Store display_vars event in a local variable
			$display_vars = $event['display_vars'];

			// Define the new config vars
			$ga_config_vars = array(
				'pushsafer_key' => array(
					'lang' => 'ACP_PUSHSAFER_ID',
					'type' => 'text:40:20',
					'explain' => true,
				),
			);

			// Add the new config vars after board_timezone in the display_vars config array
			$insert_after = array('after' => 'board_timezone');
			$display_vars['vars'] = phpbb_insert_config_array($display_vars['vars'], $ga_config_vars, $insert_after);

			// Update the display_vars event with the new array
			$event['display_vars'] = $display_vars;
		}
	}	
	
	public function __construct(\phpbb\auth\auth $auth, \phpbb\config\config $config,\phpbb\db\driver\driver_interface $db, $user, $template, $request, $php_ext, $phpbb_root_path)
	{
		$this->auth = $auth;
		$this->config = $config;
		$this->db = $db;
		$this->user = $user;
		$this->template = $template;
		$this->request = $request;
		$this->php_ext = $php_ext;
		$this->phpbb_root_path = $phpbb_root_path;
	}
	


	public function ucp_register_user_row_after($event)
	{
		$private_key = $this->config['pushsafer_key'];

		if ($this->config['require_activation'] != USER_ACTIVATION_ADMIN && $private_key!='')
		{
			// Grab an array of user_id's with a_user permissions ... these users can activate a user
			$admin_ary = $this->auth->acl_get_list(false, 'a_user', false);
			$admin_ary = (!empty($admin_ary[0]['a_user'])) ? $admin_ary[0]['a_user'] : array();

			// Also include founders
			$where_sql = ' WHERE user_type = ' . USER_FOUNDER;

			if (sizeof($admin_ary))
			{
				 $where_sql .= ' OR ' . $this->db->sql_in_set('user_id', $admin_ary);
			}

			$sql = 'SELECT user_id, username, user_email, user_lang, user_jabber, user_notify_type
				FROM ' . USERS_TABLE . ' ' . $where_sql;
			$result = $this->db->sql_query($sql);

			$data = array(
				'username'			=> $this->request->variable('username', '', true),
				'email'				=> strtolower($this->request->variable('email', '')),
				'user_regdate'		=> time(),
				'user_ip'			=> $this->user->ip,
				'lang'				=> basename($this->request->variable('lang', $this->user->lang_name)),
			);

			while ($row = $this->db->sql_fetchrow($result))
			{

				$title = file_get_contents($this->phpbb_root_path . '/ext/appzer/pushsafer/language/'.$this->config['default_lang'].'/admin_notify_registered_title.txt');
				$message = file_get_contents($this->phpbb_root_path . '/ext/appzer/pushsafer/language/'.$this->config['default_lang'].'/admin_notify_registered.txt');
				
				$message = str_replace('{USERNAME}',$data['username'],$message);
				$message = str_replace('{USER_MAIL}',$data['email'],$message);
				$message = str_replace('{USER_REGDATE}',date($this->config['default_dateformat'], $data['user_regdate']),$message);
				$message = str_replace('{USER_IP}',$data['user_ip'],$message);
			
				$apiurl = 'https://www.pushsafer.com/api';
				$data = array(
					't' => urldecode($title),
					'm' => urldecode($message),
					's' => 12,
					'v' => 1,
					'i' => 27,
					'd' => '',
					'u' => urldecode($this->config['site_home_url']),
					'k' => $private_key
				);
				$options = array(
					'http' => array(
						'header'  => "Content-type: application/x-www-form-urlencoded\r\n",
						'method'  => 'POST',
						'content' => http_build_query($data)
					)
				);
				$context  = stream_context_create($options);
				$result = file_get_contents($apiurl, false, $context);			
			}
			$this->db->sql_freeresult($result);			
		}
	}
}